is_new_reactive: Reactive Variables Definition Check

View source: R/Repro_S7.R

is_new_reactiveR Documentation

Reactive Variables Definition Check

Description

A helper function to check whether or not the reactive variables to be added to the Repro object already exists. Used to avoid duplicate definitions being added to a script.

Usage

is_new_reactive(new, exisitng)

Arguments

new, exisitng

A named list of reactive variable definitions

Value

A boolean stating whether or not there is at least one reactive definition in new that doesn't exist in existing


shinyreprex documentation built on April 27, 2026, 9:10 a.m.