| is_new_reactive | R Documentation |
A helper function to check whether or not the reactive variables to be added
to the Repro object already exists. Used to avoid duplicate definitions being
added to a script.
is_new_reactive(new, exisitng)
new, exisitng |
A named list of reactive variable definitions |
A boolean stating whether or not there is at least one reactive definition
in new that doesn't exist in existing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.