| repro_chunk | R Documentation |
Evaluate a chunk of code to extract Shiny inputs and reactives, replacing the inputs with the values selected by the user, and the reactives with the code bodies used to generate them.
repro_chunk(x, repro_code = Repro(), env = rlang::caller_env())
x |
|
repro_code |
A |
env |
The environment |
Whilst a default is provided to env, it is unlikely that this is the same environment
x is defined in. This allows the top-level reprex_reactive call to pass through
environments found for calls to other reactives in the chunk.
A Repro object containing all the necessary code and packages to recreate
the provided expression when evaluated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.