| class_reactive | R Documentation |
Additional classes to include in S7 to use in repro_code and
repro_code_chunk methods:
These variables need to be handled in a specific way to extract non-static values stored in reactive calls.
The class capturing shiny::reactive() calls
The class capturing shiny::bindCache() calls
The class capturing shiny::bindEvent() calls
The union of class_event_cache and class_event_reactive
When determining evaluating a chunk, the function name gets attached to the class of the chunk, these are special cases that need to be handled in a non-standard way.
The class capturing anonymous function definitions
The class capturing evaluated shiny::reactive() objects
The class capturing evaluated shiny::reactiveValues() objects
The class capturing if calls
The class capturing undefined calls, such as pkg::fn
The class capturing ignorable shiny function calls such as
shiny::req() and shiny::validate()
The class capturing a subset ($) call
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.